""" Defining the base background scene """
from .config import *


class Scene:
    """ Making a matrix to represent the game scene """

    def __init__(self, length, width, fullwidth):
        """ Initial matrix """
        self.start = 0
        self.length = length
        self.width = width
        self.fullwidth = fullwidth
        self.max_y = 0
        self.score = 0
        self.scenematrix = []
        # scenematrix is a matrix to display all elements
        for x in range(0, fullwidth):
            self.scenematrix.append([])
            for y in range(0, fullwidth):
                self.scenematrix[x].append(' ')
        for x in range(groundx, length):
            for y in range(0, fullwidth):
                self.scenematrix[x][y] = colors['Brown'] + '#' + RESET

    def displayScene(self, level):
        """ Print the screen to the terminal """
        sceneprint = ""
        sceneprint += colors['Yellow'] + " "*40 + "SUPER MARIO\n" + RESET
        sceneprint += colors['Cyan']+"SCORE : " +\
            str(self.score) + " "*30+"LEVEL:"+str(level) + " "*30 + \
            "LIVES:" + str(Lives.lives)+"\n"+RESET
        if self.start >= self.fullwidth - self.width:
            self.start = self.fullwidth - self.width
        for i in range(0, self.length):
            for j in range(self.start, self.start + self.width):
                sceneprint += str(self.scenematrix[i][j])
            sceneprint += '\n'
        sceneprint += colors['Cyan'] + "Press Q to exit\n" + RESET
        return sceneprint

    # auxilary functions to return and update matrix
    def returnmatrix(self):
        return self.scenematrix

    def updatescene(self, updmatrix):
        self.scenematrix = updmatrix



"""
The Token class, interchangeable with ``pygments.token``.

A `Token` has some semantics for a piece of text that is given a style through
a :class:`~prompt_toolkit.styles.Style` class. A pygments lexer for instance,
returns a list of (Token, text) tuples. Each fragment of text has a token
assigned, which when combined with a style sheet, will determine the fine
style.
"""

# If we don't need any lexers or style classes from Pygments, we don't want
# Pygments to be installed for only the following 10 lines of code. So, there
# is some duplication, but this should stay compatible with Pygments.

__all__ = (
    'Token',
    'ZeroWidthEscape',
)


class _TokenType(tuple):
    def __getattr__(self, val):
        if not val or not val[0].isupper():
            return tuple.__getattribute__(self, val)

        new = _TokenType(self + (val,))
        setattr(self, val, new)
        return new

    def __repr__(self):
        return 'Token' + (self and '.' or '') + '.'.join(self)


# Prefer the Token class from Pygments. If Pygments is not installed, use our
# minimalistic Token class.
try:
    from pygments.token import Token
except ImportError:
    Token = _TokenType()


# Built-in tokens:

#: `ZeroWidthEscape` can be used for raw VT escape sequences that don't
#: cause the cursor position to move. (E.g. FinalTerm's escape sequences
#: for shell integration.)
ZeroWidthEscape = Token.ZeroWidthEscape
